pub struct CachingDirectory<D> { /* private fields */ }Expand description
A Directory implementation wrapping another one and caching some data using
deadpool_redis.
Implementations
Sourceimpl<D> CachingDirectory<D>
impl<D> CachingDirectory<D>
Sourcepub fn new(dir: D, redis: Pool) -> Self
pub fn new(dir: D, redis: Pool) -> Self
Creates a new CachingDirectory from the given directory and pool.
The provided Directory must return a FileHandle that implements
read_bytes_async() without panicking.
This must be called from within a tokio context.
Sourceimpl<D: Directory + Clone> CachingDirectory<D>
impl<D: Directory + Clone> CachingDirectory<D>
Sourcepub fn warmer(&self) -> Warmer<D>
pub fn warmer(&self) -> Warmer<D>
Creates a Warmer that allows warming this directory’s cache.
The warmer defaults to the host’s available parallelism; configure it with
Warmer::with_concurrency.